@@ -37,6 +37,7 @@ class Database:
                 ohlc_result = json.loads(json.loads(response.content).replace("'", "\"").replace('False','0').replace('True','1'))
             else:
 
+                #result = ast.literal_eval(json.loads(response.content))
                 result = json.loads(json.loads(response.content).replace("'", "\"").replace('[(', '\"[(').replace(')]',')]\"').replace('False','0').replace('True','1'))
                 ohlc_result = result[0]
 
@@ -79,7 +80,6 @@ class Database:
 
 
             if price_adj == True:
-
                 qfq_df = qfq_df[qfq_df['date'] > 20100000]
 
                 qfq_df = qfq_df.iloc[::-1].reset_index(drop=True)
@@ -95,7 +95,6 @@ class Database:
                 t_index = pd.DatetimeIndex(pd.date_range(start=first_date, end=last_date, freq='1D'))
                 qfq_df = qfq_df.reindex(t_index)
                 qfq_df = qfq_df.fillna(method='bfill')
-                qfq_df = qfq_df.fillna(method='ffill')
                 qfq_df = qfq_df.reset_index()
                 qfq_df['index'] = qfq_df['index'].astype(str)
                 qfq_df['index'] = qfq_df['index'].str.replace('-', '')
@@ -163,6 +162,7 @@ class Database:
 
             response = requests.get(link_str)
 
+            #result = ast.literal_eval(json.loads(response.content))
             result = json.loads(json.loads(response.content).replace("'", "\""))
 
             df_list = []
@@ -225,6 +225,7 @@ class Database:
                 if year_month not in year_month_involved_list:
                     year_month_involved_list.append(year_month)
 
+            #if end_date >= int(expiry_date_dict[max(year_month_involved_list)].strftime('%Y%m%d')):
             year_month_involved_list.append((datetime.datetime.strptime(year_month_involved_list[-1], '%y%m') + relativedelta(months=1)).strftime('%y%m'))
 
             year_month_involved_list_str = json.dumps(str(year_month_involved_list))
@@ -367,6 +368,7 @@ class Database:
             df = df.sort_values(['date', 'market_cap_mil'], ascending=[True, False])
             df = df.reset_index(drop=True)
             df['date'] = pd.to_datetime(df['date'],format='%Y-%m-%d')
+            #df['record_date'] = pd.to_datetime(df['record_date'],format='%Y%m%d')
             df = df[['date','code','issued_share_mil','market_cap_mil','cumulative_market_cap_mil']]
             return df
 
@@ -406,6 +408,7 @@ class Database:
             df = df.sort_values(by='date')
             df = df.reset_index(drop=True)
             df['date'] = pd.to_datetime(df['date'],format='%Y-%m-%d')
+            #df['record_date'] = pd.to_datetime(df['record_date'],format='%Y%m%d')
             df = df[['date','code','issued_share_mil','market_cap_mil','cumulative_market_cap_mil']]
             df = df.set_index('date')
             return df
@@ -457,6 +460,7 @@ class Database:
             json_content = json_content.replace(' nan', '\" nan\"')
 
             result = ast.literal_eval(json_content)
+            #result = json.loads(json.loads(response.content).replace("'", "\""))
 
             df_list = []
             for item in result:
@@ -489,6 +493,7 @@ class Database:
         link_str = link_url + code_str + '&' + token_str + '&' + database_str
 
         response = requests.get(link_str)
+        #result = ast.literal_eval(json.loads(response.content))
         result = json.loads(json.loads(response.content).replace("'", "\""))
 
         df = pd.DataFrame(result)
@@ -618,7 +623,8 @@ class Database:
             df['date'] = pd.to_datetime(df['date'], format='%Y%m%d')
             df = df.set_index('date')
             df = df.sort_index()
-
+            #df = df.reset_index(drop=False)
+            
             for col in df.columns:
                 if 'participants_participant_' in col:
                     df = df.rename(columns={col:col.replace('participants_participant_','participants_')})
@@ -907,7 +913,6 @@ class Database:
             name_list.remove('hk_full_market')
 
         return name_list
-
     def get_all_hk_stock_plate_name(self):
 
         link_url = 'http://www.hkfdb.net/data_api?'
@@ -930,30 +935,21 @@ class Database:
         link_str = link_url + '&' + token_str + '&' + database_str
         
         response = requests.get(link_str)
-        r_content = response.content
-        json1 = json.loads(r_content).replace("'", "\"")
-        json1 = json1.replace('nan','NaN')
-        json1 = json1.replace('INT\"L','INTL')
-        json1 = json1.replace('L\"OCCITANE','LOCCITANE')
-        json1 = json1.replace('True','\"True\"')
-        json1 = json1.replace('False','\"False\"')
-
+        json1 = json.loads(response.content).replace("'", "\"").replace('nan','NaN')
         result = json.loads(json1)
 
         df = pd.DataFrame(result)
-
         df['ipo_date'] = pd.to_datetime(df['ipo_date'],format='%Y-%m-%d')
+        #df['ipo_date'] = df['ipo_date'].astype(str)
 
         df['share_issued'] = df['share_issued'].astype(str)
+        df['market_capital'] = df['market_capital'].astype(str)
+
         df['share_issued'] = df['share_issued'].str.replace('-','')
-        df['share_issued'] = df['share_issued'].astype('int64')
-
-        df = df.sort_values(by='code')
-
-        df['market_capital'] = df['market_capital'].map(lambda x:round(x,0))
-        df['market_capital'] = df['market_capital'].astype('int64')
-
-        df = df[['code','stock_name','price','PE','EPS','dividend','volume','turnover','share_issued','lot_size','market_capital','ipo_date','year_end_date', 'is_stop_trading']]
+        df['market_capital'] = df['market_capital'].str.replace('-','')
+        
+        df['share_issued'] = df['share_issued'].astype(int)
+        df['market_capital'] = df['market_capital'].astype(int)
 
         return df
 
@@ -1060,10 +1056,8 @@ class Database:
             df['date'] = pd.to_datetime(df['date'], format='%Y%m%d')
 
             df = df.set_index(keys='date')
+            #df = df.reset_index(drop=False)
             df = df.sort_index()
-            for col in df.columns:
-                df[col] = df[col].astype(int)
-
             return df
 
         else:
@@ -1119,6 +1113,7 @@ class Database:
             elif deri == 'fut':
                 df = df.sort_values(by='date')
                 df = df.set_index('date')
+                #df = df.reset_index(drop=True)
 
             if 'strike_price' in df.columns:
                 df = df.rename(columns={'strike_price': 'strike'})
